@@ -123,7 +123,7 @@ pack .xcircuit.menubar.filebutton .xcircuit.menubar.editbutton \
 
 # The bottom message bar
 
-label .xcircuit.menubar.message -text "Welcome to Xcircuit v3.1" \
+label .xcircuit.menubar.message -text "Welcome to Xcircuit v${XCIRCUIT_VERSION}" \
 	-background beige -justify left -anchor w
 pack .xcircuit.menubar.message -side top -fill x -padx 2 -ipady 3 -pady 2
 
@@ -240,7 +240,8 @@ proc xcircuit::pageupdate { {subcommand "none"} } {
 	    .output.bbar.okay configure -text "Overwrite File"
 	  }
 	  .output.bbar.okay configure -command \
-		{xcircuit::page filename [.output.textent.txt1 get]; \
+		{.output.textent.but1 invoke; \
+		 .output.textent.but2 invoke; \
 		 if {$XCOps(dmultiple) == 1} {xcircuit::page save} else { \
 		 xcircuit::page saveonly }; wm withdraw .output}
         }
@@ -381,14 +382,15 @@ xcircuit::tag color { if {"%1" == "set"} { \
 	set XCOps(colorval) %2; set iname img_co; \
 	if {"%2" != "inherit"} {append iname l%2} ; \
 	.xcircuit.mainframe.toolbar.bco configure -image $iname} }
-xcircuit::tag fill { switch -- "%1" { opaque { set XCOps(opaque) true } \
+xcircuit::tag fill { foreach i %N { switch -- "$i" { \
+	   opaque { set XCOps(opaque) true } \
 	   transparent { set XCOps(opaque) false } 0 - unfilled \
 		{set XCOps(fillamount) 0; \
 	      .xcircuit.mainframe.toolbar.bfi configure -image img_fi} \
 	   solid {set XCOps(fillamount) 100; \
 	      .xcircuit.mainframe.toolbar.bfi configure -image img_stip100}
-	   default {set XCOps(fillamount) %1; \
-	      .xcircuit.mainframe.toolbar.bfi configure -image img_stip%1} } }
+	   default {set XCOps(fillamount) $i; \
+	      .xcircuit.mainframe.toolbar.bfi configure -image img_stip$i} } } }
 xcircuit::tag parameter { if {"%1" == "set"} {xcircuit::prompteditparams \
 		{substring numeric expression}} }
 
@@ -513,7 +515,9 @@ pack .output.textent.txtf.txtp -side left -fill y
 pack .output.textent.txtf.sizb -side left
 
 button .output.textent.but1 -text Apply -bg beige \
-	-command {xcircuit::page filename [.output.textent.txt1 get];\
+	-command {xcircuit::page filename [.output.textent.txt1 get]
+	if {[llength [xcircuit::page label]] > 1} {
+	   xcircuit::page label [.output.textent.txt1 get]};\
 	.output.textent.but1 configure -text Okay}
 button .output.textent.but2 -text Apply -bg beige \
 	-command {xcircuit::page label [.output.textent.txt2 get];\
@@ -1055,9 +1059,20 @@ proc xcircuit::promptloadfile {} {
    focus .filelist.textent.txt
 }
 
+proc xcircuit::promptimportspice {} {
+   .filelist.bbar.okay configure -command \
+	{xcircuit::page import spice \
+	[.filelist.textent.txt get]; wm withdraw .filelist}
+   .filelist.listwin.win configure -data "spice"
+   .filelist.textent.title.field configure -text "Select SPICE file to import:"
+   wm deiconify .filelist
+   focus .filelist.textent.txt
+}
+
 proc xcircuit::promptimportfile {} {
    .filelist.bbar.okay configure -command \
-	{xcircuit::page import [.filelist.textent.txt get]; wm withdraw .filelist}
+	{xcircuit::page import xcircuit \
+	[.filelist.textent.txt get]; wm withdraw .filelist}
    .filelist.listwin.win configure -data "ps"
    .filelist.textent.title.field configure -text "Select file to import:"
    wm deiconify .filelist
@@ -1066,7 +1081,8 @@ proc xcircuit::promptimportfile {} {
 
 proc xcircuit::promptimportbackground {} {
    .filelist.bbar.okay configure -command \
-	{xcircuit::page background [.filelist.textent.txt get]; wm withdraw .filelist}
+	{xcircuit::page import background \
+	[.filelist.textent.txt get]; wm withdraw .filelist}
    .filelist.listwin.win configure -data "ps"
    .filelist.textent.title.field configure -text "Select file to use as background:"
    wm deiconify .filelist
@@ -1340,7 +1356,7 @@ set XCOps(jhoriz) left
 set XCOps(jvert) bottom
 set XCOps(linestyle) solid
 set XCOps(fillamount) 0
-set XCOps(opaque) 0
+set XCOps(opaque) false
 set XCOps(polyedittype) manhattan
 set XCOps(showgrid) true
 set XCOps(showsnap) true
@@ -1387,6 +1403,9 @@ set m [menu .xcircuit.menubar.filebutton.filemenu -tearoff 0]
 $m add command -label "Read XCircuit File" -command {xcircuit::promptloadfile}
 $m add command -label "Import XCircuit PS" -command {xcircuit::promptimportfile}
 $m add command -label "Import background PS" -command {xcircuit::promptimportbackground}
+if {![catch {set XCIRCUIT_ASG}]} {
+   $m add command -label "Import SPICE Deck" -command {xcircuit::promptimportspice}
+}
 $m add command -label "Execute Script" -command {xcircuit::promptexecscript}
 $m add command -label "Tcl Console" -command {xcircuit::raiseconsole}
 $m add command -label "Write XCircuit PS" -command {xcircuit::promptsavepage}
@@ -1402,8 +1421,10 @@ $m add separator
 $m add command -label "Quit" -command {quit}
 
 set m [menu .xcircuit.menubar.editbutton.editmenu -tearoff 0]
+$m add command -label "Undo" -command {undo}
+$m add command -label "Redo" -command {redo}
+$m add separator
 $m add command -label "Delete" -command {delete selected}
-$m add command -label "Undelete" -command {undelete}
 $m add command -label "Copy" -command {copy selected}
 $m add command -label "Edit" -command {edit selected}
 $m add cascade -label "Rotate/Flip" -menu $m.rotmenu
@@ -1598,8 +1619,8 @@ $m3 add radio -label "Dotted" -variable XCOps(linestyle) -value dotted \
 $m3 add radio -label "Unbordered" -variable XCOps(linestyle) -value unbordered \
 	-command {xcircuit::border $XCOps(linestyle)}
 $m3 add separator
-$m3 add check -label "Closed" -variable XCOps(polyclosed) -onvalue closed \
-	-offvalue unclosed -command {xcircuit::border  $XCOps(polyclosed)}
+$m3 add check -label "Closed" -variable XCOps(polyclosed) -onvalue true \
+	-offvalue false -command {xcircuit::border  $XCOps(polyclosed)}
 $m3 add check -label "Bounding Box" -variable XCOps(bboxtype) -onvalue true \
 	-offvalue false -command {xcircuit::border bbox $XCOps(bboxtype)}
 
@@ -1625,23 +1646,23 @@ image create bitmap img_stip100 -foreground black -background white -file \
 
 set m3 [menu $m2.fillmenu -tearoff 0]
 $m3 add radio -image img_stip100 -variable XCOps(fillamount) -value 100 \
-	-command {xcircuit::fill $XCOps(fillamount); xcircuit::fill opaque}
+	-command {xcircuit::fill $XCOps(fillamount) opaque}
 $m3 add radio -image img_stip88 -variable XCOps(fillamount) -value 88 \
-	-command {xcircuit::fill $XCOps(fillamount); xcircuit::fill opaque}
+	-command {xcircuit::fill $XCOps(fillamount) opaque}
 $m3 add radio -image img_stip75 -variable XCOps(fillamount) -value 75 \
-	-command {xcircuit::fill $XCOps(fillamount); xcircuit::fill opaque}
+	-command {xcircuit::fill $XCOps(fillamount) opaque}
 $m3 add radio -image img_stip62 -variable XCOps(fillamount) -value 62 \
-	-command {xcircuit::fill $XCOps(fillamount); xcircuit::fill opaque}
+	-command {xcircuit::fill $XCOps(fillamount) opaque}
 $m3 add radio -image img_stip50 -variable XCOps(fillamount) -value 50 \
-	-command {xcircuit::fill $XCOps(fillamount); xcircuit::fill opaque}
+	-command {xcircuit::fill $XCOps(fillamount) opaque}
 $m3 add radio -image img_stip38 -variable XCOps(fillamount) -value 38 \
-	-command {xcircuit::fill $XCOps(fillamount); xcircuit::fill opaque}
+	-command {xcircuit::fill $XCOps(fillamount) opaque}
 $m3 add radio -image img_stip25 -variable XCOps(fillamount) -value 25 \
-	-command {xcircuit::fill $XCOps(fillamount); xcircuit::fill opaque}
+	-command {xcircuit::fill $XCOps(fillamount) opaque}
 $m3 add radio -image img_stip12 -variable XCOps(fillamount) -value 12 \
-	-command {xcircuit::fill $XCOps(fillamount); xcircuit::fill opaque}
+	-command {xcircuit::fill $XCOps(fillamount) opaque}
 $m3 add radio -image img_stip0 -variable XCOps(fillamount) -value 0 \
-	-command {xcircuit::fill $XCOps(fillamount); xcircuit::fill transparent}
+	-command {xcircuit::fill $XCOps(fillamount) transparent}
 $m3 add separator
 $m3 add radio -label "Opaque" -variable XCOps(opaque) -value true \
 	-command {xcircuit::fill opaque}
@@ -1651,8 +1672,8 @@ $m3 add radio -label "Transparent" -variable XCOps(opaque) -value false \
 set m3 [menu $m2.colormenu -tearoff 0]
 $m3 add command -label "Add New Color" -command {xcircuit::picknewcolor}
 $m3 add separator
-$m3 add radio -label "Inherit Color" -variable colorval -value inherit \
-  -command {color set $colorval}
+$m3 add radio -label "Inherit Color" -variable XCOps(colorval) -value inherit \
+  -command {color set $XCOps(colorval)}
 
 set m3 [menu $m2.parammenu -tearoff 0]
 $m3 add command -label "Edit Parameters" -command \
