@@ -52,21 +52,21 @@ extern char _STR[150];
 /*----------------------------------------------------------------------*/
 
 u_char param_select[] = {
-   SEL_ANY,					/* P_NUMERIC */
+   ALL_TYPES,					/* P_NUMERIC */
    LABEL,					/* P_SUBSTRING */
-   POLYGON | SPLINE | LABEL | OBJECT | ARC,	/* P_POSITION_X */
-   POLYGON | SPLINE | LABEL | OBJECT | ARC,	/* P_POSITION_Y */
+   POLYGON | SPLINE | LABEL | OBJINST | ARC,	/* P_POSITION_X */
+   POLYGON | SPLINE | LABEL | OBJINST | ARC,	/* P_POSITION_Y */
    POLYGON | SPLINE | ARC | PATH,		/* P_STYLE */
    LABEL,					/* P_JUSTIFY */
    ARC,						/* P_ANGLE1 */
    ARC,						/* P_ANGLE2 */
    ARC,						/* P_RADIUS */
    ARC,						/* P_MINOR_AXIS */
-   LABEL | OBJECT,				/* P_ROTATION */
-   LABEL | OBJECT,				/* P_SCALE */
+   LABEL | OBJINST,				/* P_ROTATION */
+   LABEL | OBJINST,				/* P_SCALE */
    POLYGON | SPLINE | ARC | PATH,		/* P_LINEWIDTH */
-   SEL_ANY, 					/* P_COLOR (tbd) */
-   POLYGON | SPLINE | LABEL | OBJECT | ARC 	/* P_POSITION */
+   ALL_TYPES, 					/* P_COLOR (tbd) */
+   POLYGON | SPLINE | LABEL | OBJINST | ARC 	/* P_POSITION */
 };
 
 #ifdef TCL_WRAPPER
@@ -243,7 +243,7 @@ void free_element_param(genericptr thiselem, eparamptr thisepp)
 	 /* stored as an allocated string in pdata.refkey, which needs	*/
 	 /* to be free'd.						*/
 
-	 if ((thiselem->type == OBJECT) && (epp->pdata.refkey != NULL))
+	 if (IS_OBJINST(thiselem) && (epp->pdata.refkey != NULL))
 	    free(epp->pdata.refkey);
 
 	 free(epp->key);
@@ -301,7 +301,7 @@ void indicateparams(genericptr thiselem)
 		  case LABEL:
 	             UDrawCircle(&TOLABEL(&thiselem)->position, ops->which);
 		     break;
-		  case OBJECT:
+		  case OBJINST:
 	             UDrawCircle(&TOOBJINST(&thiselem)->position, ops->which);
 		     break;
 		  case POLYGON:
@@ -465,7 +465,7 @@ int opsubstitute(objectptr thisobj, objinstptr pinst)
 	 else if (ops == NULL)
 	    continue;
 
-	 if (thiselem->type == OBJECT) {
+	 if (IS_OBJINST(thiselem)) {
 	    key = epp->pdata.refkey;
 	    if (key != NULL) {
 	       objinstptr thisinst;
@@ -476,7 +476,8 @@ int opsubstitute(objectptr thisobj, objinstptr pinst)
 	       /* Sanity check: refkey must exist in object */
 	       refop = match_param(thisinst->thisobject, key);
 	       if (refop == NULL) {
-		  Fprintf("Error:  Reference key %s does not exist in object %s\n",
+		  Fprintf(stderr, "Error:  Reference key %s does not"
+				" exist in object %s\n",
 				key, thisinst->thisobject->name);
 		  continue;
 	       }
@@ -516,7 +517,7 @@ int opsubstitute(objectptr thisobj, objinstptr pinst)
 	          case LABEL:
 		     TOLABEL(&thiselem)->position.x = ival;
 		     break;
-	          case OBJECT:
+	          case OBJINST:
 		     TOOBJINST(&thiselem)->position.x = ival;
 		     break;
 	          case ARC:
@@ -538,7 +539,7 @@ int opsubstitute(objectptr thisobj, objinstptr pinst)
 	          case LABEL:
 		     TOLABEL(&thiselem)->position.y = ival;
 		     break;
-	          case OBJECT:
+	          case OBJINST:
 		     TOOBJINST(&thiselem)->position.y = ival;
 		     break;
 	          case ARC:
@@ -614,7 +615,7 @@ int opsubstitute(objectptr thisobj, objinstptr pinst)
 	          case LABEL:
 		     TOLABEL(&thiselem)->rotation = ival;
 		     break;
-	          case OBJECT:
+	          case OBJINST:
 		     TOOBJINST(&thiselem)->rotation = ival;
 		     break;
 	       }
@@ -625,7 +626,7 @@ int opsubstitute(objectptr thisobj, objinstptr pinst)
 	          case LABEL:
 		     TOLABEL(&thiselem)->scale = fval;
 		     break;
-	          case OBJECT:
+	          case OBJINST:
 		     TOOBJINST(&thiselem)->scale = fval;
 		     break;
 	       }
@@ -691,7 +692,7 @@ int psubstitute(objinstptr thisinst)
 
 Boolean has_param(genericptr celem)
 {
-   if (celem->type == LABEL) {
+   if (IS_LABEL(celem) == LABEL) {
       stringpart *cstr;
       labelptr clab = (labelptr)celem;
       for (cstr = clab->string; cstr != NULL; cstr = cstr->nextpart)
@@ -756,7 +757,7 @@ void pwriteback(objinstptr thisinst)
                switch(ops->which) {
 	          case P_POSITION_X:
 	             switch(thiselem->type) {
-	                case OBJECT:
+	                case OBJINST:
 		           wtemp.ival = TOOBJINST(&thiselem)->position.x;
 		           break;
 	                case LABEL:
@@ -776,7 +777,7 @@ void pwriteback(objinstptr thisinst)
 	             break;
 	          case P_POSITION_Y:
 	             switch(thiselem->type) {
-	                case OBJECT:
+	                case OBJINST:
 		           wtemp.ival = TOOBJINST(&thiselem)->position.y;
 		           break;
 	                case LABEL:
@@ -847,7 +848,7 @@ void pwriteback(objinstptr thisinst)
 	             break;
 	          case P_ROTATION:
 	             switch(thiselem->type) {
-	                case OBJECT:
+	                case OBJINST:
 		           wtemp.ival = TOOBJINST(&thiselem)->rotation;
 		           break;
 	                case LABEL:
@@ -857,7 +858,7 @@ void pwriteback(objinstptr thisinst)
 	             break;
 	          case P_SCALE:
 	             switch(thiselem->type) {
-	                case OBJECT:
+	                case OBJINST:
 		           wtemp.fval = TOOBJINST(&thiselem)->scale;
 		           break;
 	                case LABEL:
@@ -1041,7 +1042,7 @@ eparamptr copyeparam(eparamptr cepp, genericptr thiselem)
    eparamptr newepp;
 
    newepp = make_new_eparam(cepp->key);
-   if ((thiselem->type == OBJECT) && (cepp->pdata.refkey != NULL))
+   if (IS_OBJINST(thiselem) && (cepp->pdata.refkey != NULL))
       newepp->pdata.refkey = strdup(cepp->pdata.refkey);
    else
       newepp->pdata.pointno = cepp->pdata.pointno;
@@ -1217,7 +1218,7 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
 
    /* Parameterized strings are handled by makeparam() */
 
-   if ((*gelem)->type == LABEL && mode == P_SUBSTRING) {
+   if (IS_LABEL(*gelem) && mode == P_SUBSTRING) {
       Fprintf(stderr, "Error: String parameter passed to makenumericalp()\n");
       return;
    }
@@ -1350,7 +1351,7 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
 	          break;
 	    }
 	    break;
-         case OBJECT:
+         case OBJINST:
 	    switch(mode) {
 	       case P_POSITION_X:
 	          newops->parameter.ivalue = (int)TOOBJINST(gelem)->position.x;
@@ -1668,7 +1669,7 @@ void searchinst(objectptr topobj, objectptr refobj, char *key)
    if (topobj == NULL) return;
 
    for (pgen = topobj->plist; pgen < topobj->plist + topobj->parts; pgen++) {
-      if ((*pgen)->type == OBJECT) {
+      if (IS_OBJINST(*pgen)) {
 	 tinst = TOOBJINST(pgen);
 	 destroyinst(tinst, refobj, key);
       }
@@ -1777,7 +1778,7 @@ void unmakeparam(labelptr thislabel, stringpart *thispart)
 
    for (pgen = topobject->plist; pgen < topobject->plist + topobject->parts;
 		pgen++) {
-      if ((*pgen)->type == LABEL) {
+      if (IS_LABEL(*pgen)) {
 	 plab = TOLABEL(pgen);
 	 for (strptr = plab->string; strptr != NULL; strptr = strptr->nextpart) {
 	    if (strptr->type == PARAM_START) {
@@ -1844,11 +1845,11 @@ void unparameterize(int mode)
 
    if (mode >= 0) {
       ptype = (short)param_select[mode];
-      if (!checkselect(ptype)) objectselect(ptype);
+      if (!checkselect(ptype)) select_element(ptype);
       if (!checkselect(ptype)) return;
    }
    else
-      ptype = SEL_ANY;
+      ptype = ALL_TYPES;
 
    if ((areastruct.selects == 1) && (mode == P_SUBSTRING) && textend > 0
 		&& textend < textpos) {
@@ -1904,11 +1905,11 @@ void parameterize(int mode, char *key)
 
    if (mode >= 0) {
       ptype = (short)param_select[mode];
-      if (!checkselect(ptype)) objectselect(ptype);
+      if (!checkselect(ptype)) select_element(ptype);
       if (!checkselect(ptype)) return;
    }
    else
-      ptype = SEL_ANY;
+      ptype = ALL_TYPES;
 
    for (fselect = areastruct.selectlist; fselect < areastruct.selectlist +
             areastruct.selects; fselect++) {
@@ -1924,7 +1925,7 @@ void parameterize(int mode, char *key)
       else
 	 makenumericalp(topobject->plist + (*fselect), mode, key);
    }
-   objectdeselect();
+   unselect_all();
    setparammarks(NULL);
 }
 
