@@ -5,13 +5,19 @@
 
 /* from undo.c */
 
-extern void register_for_undo(u_int, objinstptr, ...);	/* variable argument list */
+/* Note variable argument list for register_for_undo() */
+extern void register_for_undo(u_int, u_char, objinstptr, ...);
 extern void undo_action();
 extern void redo_action();
 extern void flush_undo_stack();
 extern void flush_redo_stack();
+extern void truncate_undo_stack();
 extern void free_undo_record(Undoptr);
 extern void free_redo_record(Undoptr);
+#ifndef TCL_WRAPPER
+extern void undo_call(xcWidget, caddr_t, caddr_t);
+extern void redo_call(xcWidget, caddr_t, caddr_t);
+#endif
 
 
 /* from tclxcircuit.c */
@@ -31,7 +37,7 @@ extern char *evaluate_expr(oparamptr);
 
 extern void copyalleparams(genericptr, genericptr);
 extern void copyparams(objinstptr, objinstptr);
-extern void objectdefaults(objinstptr, objectptr, int, int);
+extern void instancedefaults(objinstptr, objectptr, int, int);
 extern void labeldefaults(labelptr, u_char, int, int);
 extern void poly_add_point(polyptr, XPoint *);
 extern void polydefaults(polyptr, int, int, int);
@@ -78,11 +84,11 @@ extern void setpage(Boolean);
 extern int changepage(short);
 extern void newpage(short);
 extern void startpush(xcWidget, caddr_t, caddr_t);
-extern void pushobject(XButtonEvent *);
+extern void pushobject(objinstptr);
 extern void push_stack(pushlistptr *, objinstptr);
 extern void pop_stack(pushlistptr *);
 extern void free_stack(pushlistptr *);
-extern void popobject(xcWidget, caddr_t, caddr_t);
+extern void popobject(xcWidget, pointertype, caddr_t);
 extern void resetbutton(xcWidget, pointertype, caddr_t);
 extern void drawhbar(xcWidget, caddr_t, caddr_t);
 extern void drawvbar(xcWidget, caddr_t, caddr_t);
@@ -104,11 +110,10 @@ extern void copyvirtual();
 extern void nextpolycycle(polyptr, short);
 extern void nextsplinecycle(splineptr, short);
 extern void nextarccycle(arcptr, short);
-extern short getkeynum();
 extern void buttonhandler(xcWidget, caddr_t, XButtonEvent *);
 extern void keyhandler(xcWidget, caddr_t, XKeyEvent *);
 extern void setsnap(short);
-extern void snapobject();
+extern void snapelement();
 extern int ipow10(int);
 extern int calcgcf(int, int);
 extern void fraccalc(float, char *);
@@ -120,7 +125,7 @@ extern void placeselects(short, short, XPoint *);
 extern void drag(xcWidget, caddr_t, XButtonEvent *);
 extern void rotatebutton(XButtonEvent *);
 extern void elemrotate(genericptr *, short);
-extern void objectrotate(short);
+extern void elementrotate(short);
 extern void edit(XButtonEvent *);
 extern void pathedit(genericptr *, short);
 extern void xc_lower(short *);
@@ -128,8 +133,8 @@ extern void xc_raise(short *);
 extern void exchange();
 extern void elhflip(genericptr *);
 extern void elvflip(genericptr *);
-extern void objectflip();
-extern void objectvflip();
+extern void elementflip();
+extern void elementvflip();
 #ifdef TCL_WRAPPER
 extern xcTimeOutProc makepress(caddr_t);
 #else
@@ -163,7 +168,7 @@ extern void pathbutton(genericptr *, XButtonEvent *);
 extern void resizearea(xcWidget, caddr_t, caddr_t);
 extern void drawarea(xcWidget, caddr_t, caddr_t);
 extern void standard_element_delete(short);
-extern void delete_for_xfer(short);
+extern void delete_for_xfer(short, short *, int);
 extern void delete_noundo(short);
 
 /* from filelist.c: */
@@ -673,7 +678,7 @@ extern void selectfilter(xcWidget, pointertype, caddr_t);
 extern Boolean checkselect(short);
 extern void geneasydraw(short, short, objectptr, objinstptr);
 extern void gendrawselected(short *, objectptr, objinstptr);
-extern short *genobjectselect(short, objectptr, objinstptr);
+extern short *genselectelement(short, u_char, objectptr, objinstptr);
 extern short *allocselect();
 extern void setoptionmenu();
 extern int test_insideness(int, int, XPoint *);
@@ -682,9 +687,11 @@ extern Boolean areaelement(genericptr *);
 extern void selectarea();
 extern void startdesel(xcWidget, caddr_t, caddr_t);
 extern void deselect(xcWidget, caddr_t, caddr_t);
-extern void drawselects();
+extern void draw_normal_selected();
+extern void draw_all_selected();
+extern void clearselects_noundo();
 extern void clearselects();
-extern void objectdeselect();
+extern void unselect_all();
 extern genericptr recurselect(short, pushlistptr *);
 #ifdef TCL_WRAPPER
 extern xcTimeOutProc startselect(caddr_t);
