@@ -234,9 +234,9 @@ static PyObject *xc_new(PyObject *self, PyObject *args)
 	 pathdefaults(*newpath, 0, 0);
 	 newgen = (genericptr *)newpath;
 	 break;
-      case OBJECT:
+      case OBJINST:
          NEW_OBJINST(newobjinst, topobject);
-	 objectdefaults(*newobjinst, NULL, 0, 0);
+	 instancedefaults(*newobjinst, NULL, 0, 0);
 	 newgen = (genericptr *)newobjinst;
 	 break;
       default:
@@ -272,7 +272,7 @@ char *type_to_string(int type)
 	 retstr = malloc(12);
 	 strcpy(retstr, "Bezier Curve");
 	 break;
-      case OBJECT:
+      case OBJINST:
 	 retstr = malloc(16);
 	 strcpy(retstr, "Object Instance");
 	 break;
@@ -305,7 +305,7 @@ int string_to_type(const char *etype)
    else if (!strcmp(etype, "Path"))
       return PATH;
    else if (!strcmp(etype, "Object Instance"))
-      return OBJECT;
+      return OBJINST;
    else
       return -1;
 }
@@ -1087,7 +1087,7 @@ static PyObject *xc_getattr(PyObject *self, PyObject *args)
    if (lstr != NULL)
       PyDict_SetItem(rdict, PyString_FromString("color"), lstr);
 
-   switch((*gelem)->type) {
+   switch(ELEMENTTYPE(*gelem)) {
       case LABEL:
 	 PyDict_SetItem(rdict, PyString_FromString("position"), 
 		make_pair(&(TOLABEL(gelem)->position)));
@@ -1153,7 +1153,7 @@ static PyObject *xc_getattr(PyObject *self, PyObject *args)
 	 }
 	 PyDict_SetItem(rdict, PyString_FromString("parts"), dlist);
 	 break;
-      case OBJECT:
+      case OBJINST:
 	 PyDict_SetItem(rdict, PyString_FromString("position"), 
 		make_pair(&(TOOBJINST(gelem)->position)));
 	 PyDict_SetItem(rdict, PyString_FromString("rotation"),
@@ -1195,7 +1195,7 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
    if ((dval = PyDict_GetItemString(attrdict, "type")) != NULL) {
       int dtype = string_to_type(PyString_AsString(dval));
       if (dtype < 0) return NULL;
-      if (dtype != (*gelem)->type) {
+      if (dtype != ELEMENTTYPE(*gelem)) {
          PyErr_SetString(PyExc_TypeError,
 		"Attempt to change the type of an object.");
          return NULL;
@@ -1213,7 +1213,7 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
       if (PyTuple_Check(dval) && PyTuple_Size(dval) == 2) {
          if ((pval = PyTuple_GetItem(dval, 0)) != NULL) {
             short xpos = (short)PyInt_AsLong(pval);
-            switch((*gelem)->type) {
+            switch(ELEMENTTYPE(*gelem)) {
 	       case ARC:
 	          TOARC(gelem)->position.x = xpos;
 	          calcarc(TOARC(gelem));
@@ -1221,7 +1221,7 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 	       case LABEL:
 	          TOLABEL(gelem)->position.x = xpos;
 	          break;
-	       case OBJECT:
+	       case OBJINST:
 	          TOOBJINST(gelem)->position.x = xpos;
 	          break;
                default:
@@ -1232,7 +1232,7 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 
          if ((pval = PyTuple_GetItem(dval, 1)) != NULL) {
             short ypos = (short)PyInt_AsLong(pval);
-            switch((*gelem)->type) {
+            switch(ELEMENTTYPE(*gelem)) {
 	       case ARC:
 	          TOARC(gelem)->position.y = ypos;
 	          calcarc(TOARC(gelem));
@@ -1240,7 +1240,7 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 	       case LABEL:
 	          TOLABEL(gelem)->position.y = ypos;
 	          break;
-	       case OBJECT:
+	       case OBJINST:
 	          TOOBJINST(gelem)->position.y = ypos;
 	          break;
                default:
@@ -1257,7 +1257,7 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 
    if ((dval = PyDict_GetItemString(attrdict, "style")) != NULL) {
       short dstyle = (short)PyInt_AsLong(dval);
-      switch((*gelem)->type) {
+      switch(ELEMENTTYPE(*gelem)) {
          case POLYGON:
 	    TOPOLY(gelem)->style = dstyle;
 	    break;
@@ -1278,7 +1278,7 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 
    if ((dval = PyDict_GetItemString(attrdict, "linewidth")) != NULL) {
       float dwidth = (float)PyFloat_AsDouble(dval);
-      switch((*gelem)->type) {
+      switch(ELEMENTTYPE(*gelem)) {
          case POLYGON:
 	    TOPOLY(gelem)->width = dwidth;
 	    break;
@@ -1299,11 +1299,11 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 
    if ((dval = PyDict_GetItemString(attrdict, "scale")) != NULL) {
       float dscale = (float)PyFloat_AsDouble(dval);
-      switch((*gelem)->type) {
+      switch(ELEMENTTYPE(*gelem)) {
          case LABEL:
 	    TOLABEL(gelem)->scale = dscale;
 	    break;
-         case OBJECT:
+         case OBJINST:
 	    TOOBJINST(gelem)->scale = dscale;
 	    break;
          default:
@@ -1314,11 +1314,11 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 
    if ((dval = PyDict_GetItemString(attrdict, "rotation")) != NULL) {
       float drot = (float)PyFloat_AsDouble(dval);
-      switch((*gelem)->type) {
+      switch(ELEMENTTYPE(*gelem)) {
          case LABEL:
 	    TOLABEL(gelem)->rotation = drot;
 	    break;
-         case OBJECT:
+         case OBJINST:
 	    TOOBJINST(gelem)->rotation = drot;
 	    break;
          default:
@@ -1329,7 +1329,7 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 
    /* Dictionary entries specific to certain xcircuit types */
 
-   switch((*gelem)->type) {
+   switch(ELEMENTTYPE(*gelem)) {
       case LABEL:
 	 if ((dval = PyDict_GetItemString(attrdict, "justify")) != NULL) {
 	    TOLABEL(gelem)->justify = PyInt_AsLong(dval);
