@@ -348,7 +348,7 @@ Boolean setobjecttype(objectptr cschem)
 	 cschem->schemtype = SYMBOL;
       if (cschem->symschem == NULL) {
          for (cgen = cschem->plist; cgen < cschem->plist + cschem->parts; cgen++) {
-            if ((*cgen)->type == LABEL) {
+            if (IS_LABEL(*cgen)) {
                clab = TOLABEL(cgen);
 	       if (clab->pin == INFO) {
 	          cschem->schemtype = FUNDAMENTAL;
@@ -431,7 +431,7 @@ void dopintype(xcWidget w, pointertype mode, caddr_t calldata)
       }
 
    if (savetype >= 0) {
-      objectdeselect();
+      unselect_all();
       drawarea(NULL, NULL, NULL);
       Wprintf(typestr);
    }
@@ -569,7 +569,7 @@ int findsubschems(int toppage, objectptr cschem, int level, short *pagelist)
    if (level == HIERARCHY_LIMIT) return -1;	/* sanity check */
 
    for (cgen = cschem->plist; cgen < cschem->plist + cschem->parts; cgen++) {
-      if ((*cgen)->type == OBJECT) {
+      if (IS_OBJINST(*cgen)) {
 	 objectptr cobj = TOOBJINST(cgen)->thisobject;
 
 	 if (cobj->symschem != NULL) {
@@ -655,7 +655,7 @@ void copypinlabel(labelptr pinlab)
 
       for (tgen = schemobj->plist; tgen < schemobj->plist + schemobj->parts;
 		tgen++) {
-         if ((*tgen)->type == LABEL) {
+         if (IS_LABEL(*tgen)) {
 	    tlabel = TOLABEL(tgen);
 	    if (!stringcomp(tlabel->string, pinlab->string)) return;
          }
@@ -757,7 +757,7 @@ void changeotherpins(labelptr newlabel, stringpart *oldstring)
    if (other == NULL) return;
 
    for (tgen = other->plist; tgen < other->plist + other->parts; tgen++) {
-      if ((*tgen)->type == LABEL) {
+      if (IS_LABEL(*tgen)) {
 	 tlab = TOLABEL(tgen);
 	 if (!stringcomp(tlab->string, oldstring)) {
 	    if (newlabel != NULL) {
@@ -853,7 +853,7 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
 
       for (plab = savepage->plist; plab < savepage->plist + savepage->parts;
 		plab++) {
-	 if ((*plab)->type == LABEL) {
+	 if (IS_LABEL(*plab)) {
 	    genericptr *tgen;
 	    labelptr tlab, lpin = (labelptr)*plab;
 
@@ -864,7 +864,7 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
 	       lflag = False;
                for (tgen = topobject->plist; tgen <
 			topobject->plist + topobject->parts; tgen++) {
-		  if ((*tgen)->type == LABEL) {
+		  if (IS_LABEL(*tgen)) {
 		     tlab = TOLABEL(tgen);
 	             if (!stringcomp(tlab->string, lpin->string)) lflag = True;
 		  }
