@@ -2302,7 +2302,7 @@ void pre_initialize()
    areastruct.gridon = True;
    areastruct.center = True;
    areastruct.bboxon = False;
-   areastruct.filter = SEL_ANY;
+   areastruct.filter = ALL_TYPES;
    areastruct.filefilter = True;
    areastruct.editinplace = True;
    areastruct.selects = 0;
